Learn R Programming

INTRIGUE (version 0.1.0)

bf.cal.cefn: Bayes Factor Calculation Scheme for CENF prior

Description

A function that calculates bayes factor for each data pair on each grid point in log scale.

Usage

bf.cal.cefn(data, hyperparam)

Arguments

data

A dataset which is constructed by pairs of coefficient values \( \beta \) and standard errors \( se(\beta)\).

hyperparam

A two-dimensional vector denoting all the grid points, namely, \(k\) x \(\omega\).

Value

A list records all the log scale bayes factor values.