Learn R Programming

INTRIGUE (version 0.1.0)

bf.cal.meta: Bayes Factor Calculation Scheme for META prior

Description

A function that calculates bayes factor for each data pair on each grid point in log scale.

Usage

bf.cal.meta(data, hyperparam = NULL, bf.only = FALSE)

Arguments

data

A dataset which is constructed by pairs of coefficient values \( \beta \) and standard errors \( se(\beta)\).

hyperparam

A two-dimensional vector denoting all the grid points, namely, \(\phi\) x \(\omega\).

bf.only

A boolean, denoting whether this function is called to calculate Bayes factor for META prior only. Usually used when publication bias issue is the target.

Value

A list records all the log scale bayes factor values or a list records log scale bayes factor for null, reproducible and irreproducible model (when bf.only=TRUE).