powered by
A function that describes the updating process in E step and M step for EM algorithm. It will be used in SQUAREM package.
bf.em(w, bf)
The weight vector in previous M step.
A vector recording all the bayes factor values in log scale.
The updated weight vector in current M step(wnew).