powered by
Calculate the updated loglikelihood value in EM algorithm, and to evaluate whether converge or not.
bf.loglik(w, bf)
The current weight vector
A vector recording all the bayes factor values in log scale.
Negative summation of loglikelihood values.