Evaluating the overall and individually heterogeneity and reproducibility for the given individuals(units) shared in different replicates.
hetero(
data,
use_cefn = TRUE,
rep = NULL,
irre = NULL,
phi_min = NULL,
phi_max = NULL,
sq_em_tol = 1e-04,
fdr.level = NULL,
sample_size = NULL
)A dataset which is constructed by pairs of coefficient values \( \beta \) and standard errors \( se(\beta)\).
A boolean, denoting whether to use CEFN prior. If the value is TRUE, CEFN prior is used, else, META prior is applied. The default value is TRUE.
A vector, denoting all the \(k^2\) (under CEFN prior) or \(r\) (under META prior) values constructing the reproducible signals. If not specified, the default one is c(0.105,0.260,0.369), which corresponds to the several prior values satisfy that \(Pr(\beta_{i,1}, \beta_{i,2} have a same sign)=0.99, 0.975, 0.95\) for CEFN prior.
A vector, denoting all the \(k^2\) or \(r\) values constructing the irreproducible signals. If not specified, the default one is c(2.198, 3.636, 6.735), which corresponds to the several prior values satisfy that \(Pr(\beta_{i,1}, \beta_{i,2} have a same sign)=0.75, 0.70, 0.65\) for CEFN prior.
A value which determines the maximum \(phi\). If not specified, will be constructed from the input datasets.
A value which determines the minimum \(phi\). If not specified, will be constructed from the input datasets.
A small, positive scalar that determines when iterations should be terminated in squarem algorithm. The default value is \(1e-4\).
The user-defined rejection level for false discovery rate.
The user-defined sample size.
A list with the following components:
The final optimal weight vector evaluated on each grid point.
A matrix denoting the converged probability for each individual being inside the three different groups, namely, the null, the reproducible and the irreproducible group.
The estimated proportion value for the three different groups, namely, the null, the reproducible and the irreproducible group.
The local false discovery rate based on the null hyppthesis of unit belonging to \(H_R\), reproducible group. \(lfdr=1-Pr(H_R)\)
If fdr.level is specified, a significant object recording True or False will be returned
# NOT RUN {
data("heterodata")
# }
# NOT RUN {
hetero.out<-hetero(heterodata,fdr.level=0.05)
names(hetero.out)
print(hetero.out$est_prop)
# }
# NOT RUN {
## for CRAN check
hetero.out<-hetero(heterodata[1:100,],fdr.level=0.05)
# }
Run the code above in your browser using DataLab