hetero.lfdr: Local False Discovery Rate Evaluation
Description
Local False Discovery Rate Evaluation
Usage
hetero.lfdr(cat, fdr.level)
Arguments
cat
The final individual-level probabilities of falling into three
categories, separately.
fdr.level
Rejection level for Local false discovery rate, if not specified, the rejection
decision procedure won't be run.
Value
A list that preserves local false discovery rate and 5tthe corresponding reject
decision if called.