A function that calculates bayes factor for each data pair on each grid point in log scale.
bf.cal.cefn(data, hyperparam)A dataset which is constructed by pairs of coefficient values \( \beta \) and standard errors \( se(\beta)\).
A two-dimensional vector denoting all the grid points, namely, \(k\) x \(\omega\).
A list records all the log scale bayes factor values.