A function that calculates bayes factor for each data pair on each grid point in log scale.
bf.cal.meta(data, hyperparam = NULL, bf.only = FALSE)A dataset which is constructed by pairs of coefficient values \( \beta \) and standard errors \( se(\beta)\).
A two-dimensional vector denoting all the grid points, namely, \(\phi\) x \(\omega\).
A boolean, denoting whether this function is called to calculate Bayes factor for META prior only. Usually used when publication bias issue is the target.
A list records all the log scale bayes factor values or a list records log scale bayes factor for null, reproducible and irreproducible model (when bf.only=TRUE).